/* Diavolo Preferences and Settings Header File

    1995 Martin Korndrfer

   V 1.30
*/


/* The following structures contains all settings for Diavolo. Use them
   with DAPI_ASKPREFS and DAPI_CHANGEPREFS (see below) to change the
   settings of Diavolo.

   ATTENTION!

   Please be careful WHAT and HOW you change. We can't give any guarantees
   if one of these settings is used irregularly.

*/


/* *********************************************************************** */
/* *********************************************************************** */
/*                                                                         */
/* SCSI Settings                                                           */
/*                                                                         */
/* *********************************************************************** */
/* *********************************************************************** */

#define MAXCHAR_CATPATH     400
#define MAXCHAR_DESTPATH    400
#define MAXCHAR_DESTDEVICE  31

/* SCSI Settings. Be EXTREMLY careful what you're doing here! Best not
   to mess with these settings. */

struct SCSIData
    {
        ULONG                   scsi_Magic;                 /* Must be set to SCSI_MAGIC value below */
        ULONG                   scsi_Length;                /* Must be set to sizeof(struct SCSIData) */

        BOOL                    scsi_Ok;                    /* Settings valid */
        UBYTE                   scsi_DeviceType;            /* SCSI Device type. Must be 1 = Seq. tape */
        UBYTE                   scsi_Version;               /* SCSI 1 or 2 */
        BOOL                    scsi_Removable;             /* Medium removable */
        char                    scsi_Vendor[9];             /* Device vendor as reported by SCSI_INQUIRY */
        char                    scsi_ProductID[17];         /* Device Product ID */
        char                    scsi_Revision[5];           /* Device SW revision */
        BOOL                    scsi_WriteProtect;          /* Device write protected */
        ULONG                   scsi_MinBlockLength;        /* Reported min. block size */
        ULONG                   scsi_MaxBlockLength;        /* Reported max. block size */
        ULONG                   scsi_MaxTransfer;           /* SCSI buffer size */
        UWORD                   scsi_MemType;               /* SCSI buffer memory type. See below. */
        ULONG                   scsi_BlockSize;             /* Size of one transfer block */
        ULONG                   scsi_MaxBlockSize;          /* Max. size of one transfer block */
        BOOL                    scsi_CngBuffered;           /* 'Buffered' flag can be altered */
        BOOL                    scsi_Buffered;              /* Enable SCSI device buffer */
        BOOL                    scsi_CngFixedBlock;         /* 'Fixed blocks' can be altered */
        BOOL                    scsi_FixedBlock;            /* Use fixed block size */
        BOOL                    scsi_CngPartition;          /* Partition setting not used yet! */
        UWORD                   scsi_CatalogDest;           /* Destination of Catalog. See below.
                                                               Only CATALOG_PATH valid right now */
        ULONG                   scsi_CatalogSize;           /* Not used yet */
        char                    scsi_CatalogPath[MAXCHAR_CATPATH + 2];  /* Path of catalog files */
        BOOL                    scsi_CngSetMark;            /* 'SetMark' can be altered */
        BOOL                    scsi_SetMark;               /* Use Setmarks instead of Filemarks */
        BOOL                    scsi_CngLocate;             /* 'Fast locate' can be altered */
        BOOL                    scsi_Locate;                /* 'Fast locate' enabled */
        BOOL                    scsi_CngSeek;               /* 'Direct seek' can be altered */
        BOOL                    scsi_Seek;                  /*'Direct seek' enabled */
        BOOL                    scsi_CngOverwrite;          /* 'Update-in-place' can be altered */
        BOOL                    scsi_Overwrite;             /* 'Update-in-place' enabled */
        BOOL                    scsi_CngCompression;        /* 'HW Compression' can be altered */
        BOOL                    scsi_Compression;           /* 'HW Compression' enabled */
        BOOL                    scsi_CngSpeedCtrl;          /* 'HW speed ctrl.' can be altered */
        BOOL                    scsi_SpeedCtrl;             /* 'HW speed ctrl.' enabled */
        UBYTE                   scsi_MaxPartitions;         /* Max. number of partitions supported by device */
        UBYTE                   scsi_NumPartitions;         /* Actual number of partitions on tape */
        UWORD                   scsi_SizePartition;         /* Size of partition 0 */
        ULONG                   scsi_SizeAllPartitions;     /* Size of all partitions */
        ULONG                   scsi_PartitionFlags;        /* Not used, values see below */
        UBYTE                   scsi_Dummy[30];             /* Reserved */
    };

#define SCSI_MAGIC          0x27fd82c1                      /* Magic value for SCSIData above */

#define SCSI_PF_FIXED       (1 << 0)                        /* Not used yet */
#define SCSI_PF_SDP         (1 << 1)
#define SCSI_PF_IDP         (1 << 2)

#define MEMTYPE_CHIP        0                               /* for scsi_Memtype */
#define MEMTYPE_DMA         1
#define MEMTYPE_ANY         2

#define CATALOG_PATH        0                               /* for scsi_CatalogDest. Only CATALOG_PATH is */
#define CATALOG_PARTITION   1                               /* valid right now */
#define CATALOG_NONE        2



/* *********************************************************************** */
/* *********************************************************************** */
/*                                                                         */
/* Preferences                                                             */
/*                                                                         */
/* *********************************************************************** */
/* *********************************************************************** */


/* PrefsSnapshot is used to save window positions and sizes */

struct PrefsSnapshot
    {
        WORD                    Left, Top, Width, Height;   /* Set all to -1 to center on screen */
    };

struct PrefsFile
    {
        ULONG                   prf_Magic;              /* Must be set to PRF_MAGIC value below */
        ULONG                   prf_Length;             /* Must be set to sizeof(struct PrefsFile) */

        BOOL                    prf_UseDrive[4];        /* Which disk drives will be used for operation */
        BOOL                    prf_VerifyWrite;        /* Verify disk writes */
        UBYTE                   prf_BackupMedium;       /* Medium to save to. See values below */

        char                    prf_UseDOSFile[MAXCHAR_DESTPATH];
                                                        /* Filename for backup to file */
        char                    prf_UseDeviceName[MAXCHAR_DESTDEVICE];
                                                        /* Devicename for backup to SCSI tape */
        int                     prf_UseDeviceUnit;      /* Deviceunit for backup to SCSI tape */

        ULONG                   prf_PufferSizeFac;      /* Global buffer size in 40kB blocks.
                                                           ~0 for max. available */
        BOOL                    prf_NumDispShort;       /* TRUE for 12.34 MB display */
        BYTE                    prf_SenderTaskPri;      /* Taskpri for hd read/write task */
        BYTE                    prf_PackerTaskPri;      /* Taskpri for packing/unpacking */
        BYTE                    prf_ReceiverTaskPri;    /* Taskpri for backup medium task */

        BYTE                    prf_PackerNum;          /* Used packer. 0 = NoPacker, 1 = LowEff... */
        char                    prf_Packer[5][15];      /* Packer for each level (e.g. NUKE.5) */
        BOOL                    prf_AskPw;              /* TRUE to ask backup title and password */
        BOOL                    prf_CheckDOS;           /* Check disks for DOS format */
        BOOL                    prf_CheckBack;          /* Check disks for Diavolo format */

        BYTE                    prf_OverwrtMode;        /* Action if file exists while restore.
                                                           See below for details. */

        BOOL                    prf_ClearArchiveFlags;  /* TRUE to *SET* archive flags after backup
                                                           (sorry, a somewhat mistaken name here :) */

        BOOL                    prf_UseDirStructure;    /* TRUE to restore dir. structure */

        struct  SCSIData        prf_SCSI;               /* SCSI Prefs. See below */

        BOOL                    prf_UseExAll;           /* Use ExAll to scan data */
        BOOL                    prf_FollowLinks;        /* FALSE to save HLed directories */
        BOOL                    prf_IgnoreHLinks;       /* FALSE to save HLed files */
        BOOL                    prf_RecursionCheck;     /* Unused, set to TRUE */

        BOOL                    prf_DeviceVerify;       /* Automatic verify SCSI tapes after backup */

        struct  PrefsSnapshot   prf_MenuSnapshot;       /* Window position and sizes */
        struct  PrefsSnapshot   prf_DeviceSnapshot;     /* Use -1 to center window */
        struct  PrefsSnapshot   prf_SelectSnapshot;
        struct  PrefsSnapshot   prf_BackupSnapshot;
        struct  PrefsSnapshot   prf_RestoreSnapshot;
        struct  PrefsSnapshot   prf_VerifySnapshot;
        struct  PrefsSnapshot   prf_ScanSnapshot;
        struct  PrefsSnapshot   prf_GlobOptSnapshot;
        struct  PrefsSnapshot   prf_BackOptSnapshot;
        struct  PrefsSnapshot   prf_RestOptSnapshot;
        struct  PrefsSnapshot   prf_SCSIOptSnapshot;
        struct  PrefsSnapshot   prf_TapeIndexSnapshot;
        struct  PrefsSnapshot   prf_PasswordSnapshot;
        struct  PrefsSnapshot   prf_FilterSnapshot;
    };

#define PRF_MAGIC       0xa687b26c                          /* Magic value for PrefsFile above */


#define MEDIUM_DOS              1                           /* prf_BackupMedium */
#define MEDIUM_DISK             0
#define MEDIUM_DEVICE           2

#define OVERWRT_ASK             0                           /* prf_OverwrtMode */
#define OVERWRT_NOT             1
#define OVERWRT_ALWAYS          2
#define OVERWRT_OLDER           3
#define OVERWRT_RENOLD          4
#define OVERWRT_RENNEW          5


